@@ -13,13 +13,6 @@ class CouchbasekitException(Exception):
     pass
 
 
-class CredentialsNotSetError(CouchbasekitException):
-    """Raised when your :class:`couchbasekit.connections.Connection`
-    credentials are not set.
-    """
-    pass
-
-
 class DoesNotExist(CouchbasekitException):
     """Raised when a model class passed with an id to be fetched, but not
     found within couchbase.
@@ -34,10 +27,10 @@ class DoesNotExist(CouchbasekitException):
             # some useful code here
             pass
     """
-    def __init__(self, obj, key):
+    def __init__(self, doc):
         msg = "{doc} document with the key '{key}' not found.".format(
-            doc=type(obj).__name__,
-            key=key,
+            doc=type(doc).__name__,
+            key=doc.doc_id,
         )
         super(DoesNotExist, self).__init__(msg)
 
